#ifndef KSTARTSUPPLICANTDLG_H
#define KSTARTSUPPLICANTDLG_H
/** KWlan
 *
 *  This File is part of KWlan, a network Manager for KDE.
 *  KWlan is distributed under LGPL license.
 *
 *	@author Thomas Michel <tom.michel@arcor.de>
 */

#include "kstartsupplicant.h"

class KStartSupplicantDlg : public KStartSupplicant
{
  Q_OBJECT

public:
  KStartSupplicantDlg(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
  ~KStartSupplicantDlg();
  /*$PUBLIC_FUNCTIONS$*/
  QString getInterface();
  QString getDriver();
  bool m_start;

public slots:
  /*$PUBLIC_SLOTS$*/
  virtual void          setData(QString *interface = NULL, QString *driver = NULL);
  virtual void          Cancel();
  virtual void          startSupplicant();

protected:
  /*$PROTECTED_FUNCTIONS$*/

protected slots:
  /*$PROTECTED_SLOTS$*/

};

#endif


